#!/bin/sh
# set up the appropriate MCR
# then run callCNVs
#
# arguments for callCNVs.m
# input data file
# tab delimited, with header line
#       i.e. chr    pos    sample   sample2 ...
INPUT_FILE="test.dat"; 


DO_LOESS_SMOOTH=1; # do Loess smoothing
W=20; # Loess smoothing window (will use 20 probes left + 20 probe on the right)
# Optimization of the separation between GMM components
# the 2 following variables are to adjust the boundaries of the Gaussian Mixture Component, this is done using an optimization algorithm
# if optimization is not reached (i.e. due to noisy ratios), they will not be any CNV call at this probe for all samples, their CN status will be 0
# and there will be a warning : "Exiting: Maximum number of iterations has been exceeded - increase MaxIter option. "
# increasing these 2 variables can help but will considerably increase the run time.
MAX_FUN_CALL=10000; # nb of optimization function call
MAX_FUN_ITER=5000; # nb of iterations for each optimization function call

##############################################
### PLEASE DO NOT MODIFY BELOW 
#############################################
# Sets up the MCR environment for the current $ARCH and executes 
# the specified command.
#
echo "------------------------------------------"
if [ "x$1" = "x" ]; then
  echo Usage:
  echo    $0 \<deployedMCRroot\> args
else
  echo Setting up environment variables
  MCRROOT=$1
  echo ---
  MWE_ARCH="glnxa64" ;
  if [ "$MWE_ARCH" = "sol64" ] ; then
	LD_LIBRARY_PATH=.:/usr/lib/lwp:${MCRROOT}/runtime/glnxa64 ; 
  else
  	LD_LIBRARY_PATH=.:${MCRROOT}/runtime/glnxa64 ;
  fi
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/bin/glnxa64 ;
  LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRROOT}/sys/os/glnxa64;
  if [ "$MWE_ARCH" = "mac" -o "$MWE_ARCH" = "maci" ]; then
	DYLD_LIBRARY_PATH=${DYLD_LIBRARY_PATH}:/System/Library/Frameworks/JavaVM.framework/JavaVM:/System/Library/Frameworks/JavaVM.framework/Libraries;
  else
	MCRJREVER=`cat ${MCRROOT}/sys/java/jre/glnxa64/jre.cfg` ; 
	echo Found MCR Java JRE version: $MCRJREVER ; 
	MCRJRE=${MCRROOT}/sys/java/jre/glnxa64/jre${MCRJREVER}/lib/amd64 ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/native_threads ; 
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/server ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE}/client ;
	LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${MCRJRE} ;  
  fi
  XAPPLRESDIR=${MCRROOT}/X11/app-defaults ;
  export LD_LIBRARY_PATH;
  export XAPPLRESDIR;
  echo LD_LIBRARY_PATH is ${LD_LIBRARY_PATH};
  shift 1
  echo "------------------------------------------"
  echo "Calling callCNVs"
  ./callCNVs $INPUT_FILE $W $DO_LOESS_SMOOTH $MAX_FUN_CALL $MAX_FUN_ITER

fi
exit
